[RFC PATCH v3 21/21] apps: lc-compliance: Rename `CaptureUnbalanced`
Barnabás Pőcze
pobrn at protonmail.com
Thu Jan 30 12:51:50 CET 2025
Rename the test to `StopWithRequestsQueued` for more clarity.
Suggested-by: Jacopo Mondi <jacopo.mondi at ideasonboard.com>
Signed-off-by: Barnabás Pőcze <pobrn at protonmail.com>
---
src/apps/lc-compliance/tests/capture_test.cpp | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/src/apps/lc-compliance/tests/capture_test.cpp b/src/apps/lc-compliance/tests/capture_test.cpp
index db1d52fc9..39761f9b1 100644
--- a/src/apps/lc-compliance/tests/capture_test.cpp
+++ b/src/apps/lc-compliance/tests/capture_test.cpp
@@ -104,13 +104,13 @@ TEST_P(SimpleCapture, CaptureStartStop)
}
/*
* Test unbalanced stop
*
* Makes sure the camera supports a stop with requests queued. Example failure
* is a camera that does not handle cancelation of buffers coming back from the
* video device while stopping.
*/
-TEST_P(SimpleCapture, UnbalancedStop)
+TEST_P(SimpleCapture, StopWithRequestsQueued)
{
const auto &[roles, numRequests] = GetParam();
@@ -104,13 +104,13 @@ TEST_P(SimpleCapture, CaptureStartStop)
}
/*
- * Test unbalanced stop
+ * Test stop with queued requests
*
* Makes sure the camera supports a stop with requests queued. Example failure
--
2.48.1
More information about the libcamera-devel
mailing list